@@ -1,8 +1,8 @@
 # Copyright 2017 Palantir Technologies, Inc.
 import logging
 from multiprocessing import dummy as multiprocessing
-
-from . import config, lsp, _utils
+from . import lsp, _utils
+from .config import config
 from .language_server import LanguageServer
 from .workspace import Workspace
 
@@ -13,10 +13,13 @@ LINT_DEBOUNCE_S = 0.5  # 500 ms
 
 
 class PythonLanguageServer(LanguageServer):
+    # pylint: disable=too-many-public-methods,redefined-builtin
 
     workspace = None
     config = None
 
+    _pool = multiprocessing.Pool(PLUGGY_RACE_POOL_SIZE)
+
     def _hook_caller(self, hook_name):
         return self.config.plugin_manager.subset_hook_caller(hook_name, self.config.disabled_plugins)
 
@@ -53,7 +56,6 @@ class PythonLanguageServer(LanguageServer):
     def initialize(self, root_uri, init_opts, _process_id):
         self.workspace = Workspace(root_uri, lang_server=self)
         self.config = config.Config(root_uri, init_opts)
-        self._pool = multiprocessing.Pool(PLUGGY_RACE_POOL_SIZE)
         self._hook('pyls_initialize')
 
     def code_actions(self, doc_uri, range, context):
@@ -70,7 +72,7 @@ class PythonLanguageServer(LanguageServer):
         )
         return {
             'isIncomplete': False,
-            'items': flatten(completions)
+            'items': completions or []
         }
 
     def definitions(self, doc_uri, position):
@@ -147,14 +149,14 @@ class PythonLanguageServer(LanguageServer):
     def m_text_document__document_symbol(self, textDocument=None, **_kwargs):
         return self.document_symbols(textDocument['uri'])
 
-    def m_text_document__formatting(self, textDocument=None, options=None, **_kwargs):
+    def m_text_document__formatting(self, textDocument=None, _options=None, **_kwargs):
         # For now we're ignoring formatting options.
         return self.format_document(textDocument['uri'])
 
     def m_text_document__rename(self, textDocument=None, position=None, newName=None, **_kwargs):
         return self.rename(textDocument['uri'], position, newName)
 
-    def m_text_document__range_formatting(self, textDocument=None, range=None, options=None, **_kwargs):
+    def m_text_document__range_formatting(self, textDocument=None, range=None, _options=None, **_kwargs):
         # Again, we'll ignore formatting options for now.
         return self.format_range(textDocument['uri'], range)
 
